.. _homogenization-linear_elastic_mM:

homogenization/linear_elastic_mM.py
===================================

**Description**


Linear elasticity with effective macroscopic properties determined
according to the theory of homogenization from a periodic microstructure.




:download:`source code </../sfepy/examples/homogenization/linear_elastic_mM.py>`

.. literalinclude:: /../sfepy/examples/homogenization/linear_elastic_mM.py

